CoexCounters

Struct CoexCounters 

pub struct CoexCounters {
    pub requests: Option<u64>,
    pub grant_immediate: Option<u64>,
    pub grant_wait: Option<u64>,
    pub grant_wait_activated: Option<u64>,
    pub grant_wait_timeout: Option<u64>,
    pub grant_deactivated_during_request: Option<u64>,
    pub delayed_grant: Option<u64>,
    pub avg_delay_request_to_grant_usec: Option<u32>,
    pub grant_none: Option<u64>,
    /* private fields */
}
Counters associated with RF Coexistance.

Some counters are only valid for RX or TX. See this for more info.

Fields

requests: Option<u64>

The number of requests

grant_immediate: Option<u64>

The number of requests while grant was active

grant_wait: Option<u64>

The number of requests while grant was inactive

grant_wait_activated: Option<u64>

The number of requests while grant was inactive that were ultimately granted

grant_wait_timeout: Option<u64>

The number of requests while grant was inactive that timed out

grant_deactivated_during_request: Option<u64>

The number of requests that were in progress when grant was deactivated

delayed_grant: Option<u64>

The number of requests that were not granted within 50µs

avg_delay_request_to_grant_usec: Option<u32>

The average time in µsec from request to grant

grant_none: Option<u64>

The number of requests that completed without receiving grant.

Receive only.